# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountDigestActualMonthlyResponse(Model):
    """AccountDigestActualMonthlyResponse.

    :param account_code: The account code
    :type account_code: str
    :param account_info: The account info
    :type account_info: str
    :param account_id: The account identifier
    :type account_id: int
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param global_use_unit:
    :type global_use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param commodities: An array of monthly data per commodity
    :type commodities:
     list[~energycap.sdk.models.AccountDigestActualMonthlyResponseCommodityData]
    :param results: An array of monthly data
    :type results:
     list[~energycap.sdk.models.AccountDigestActualMonthlyResponseResults]
    """

    _attribute_map = {
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'account_id': {'key': 'accountId', 'type': 'int'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'global_use_unit': {'key': 'globalUseUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'commodities': {'key': 'commodities', 'type': '[AccountDigestActualMonthlyResponseCommodityData]'},
        'results': {'key': 'results', 'type': '[AccountDigestActualMonthlyResponseResults]'},
    }

    def __init__(self, **kwargs):
        super(AccountDigestActualMonthlyResponse, self).__init__(**kwargs)
        self.account_code = kwargs.get('account_code', None)
        self.account_info = kwargs.get('account_info', None)
        self.account_id = kwargs.get('account_id', None)
        self.updated = kwargs.get('updated', None)
        self.global_use_unit = kwargs.get('global_use_unit', None)
        self.cost_unit = kwargs.get('cost_unit', None)
        self.commodities = kwargs.get('commodities', None)
        self.results = kwargs.get('results', None)
