# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalendarizedCalculationRequest(Model):
    """Adding calculation involving meters
    You must pass in at least 1 thing to sum.

    :param sum:
    :type sum: ~energycap.sdk.models.CalendarizedSumRequest
    """

    _attribute_map = {
        'sum': {'key': 'sum', 'type': 'CalendarizedSumRequest'},
    }

    def __init__(self, *, sum=None, **kwargs) -> None:
        super(CalendarizedCalculationRequest, self).__init__(**kwargs)
        self.sum = sum
