# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillDemandRequest(Model):
    """CalculatedBillDemandRequest.

    :param readings_channel_id: Use channel data readings to calculate bill
     demand <span class='property-internal'>Required (defined)</span>
    :type readings_channel_id: int
    :param fixed_demand:
    :type fixed_demand: ~energycap.sdk.models.FixedDemandRequest
    :param use_wattics_data_point: Use Wattics data readings to calculate bill
     demand <span class='property-internal'>Required (defined)</span>
    :type use_wattics_data_point: bool
    """

    _attribute_map = {
        'readings_channel_id': {'key': 'readingsChannelId', 'type': 'int'},
        'fixed_demand': {'key': 'fixedDemand', 'type': 'FixedDemandRequest'},
        'use_wattics_data_point': {'key': 'useWatticsDataPoint', 'type': 'bool'},
    }

    def __init__(self, *, readings_channel_id: int=None, fixed_demand=None, use_wattics_data_point: bool=None, **kwargs) -> None:
        super(CalculatedBillDemandRequest, self).__init__(**kwargs)
        self.readings_channel_id = readings_channel_id
        self.fixed_demand = fixed_demand
        self.use_wattics_data_point = use_wattics_data_point
