# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListCreateResponse(Model):
    """ListCreateResponse.

    :param list_id: The list identifier.
    :type list_id: int
    :param list_info: The list name.
    :type list_info: str
    :param list_description: The list description.
    :type list_description: str
    :param list_type:
    :type list_type: ~energycap.sdk.models.ListTypeChild
    :param user:
    :type user: ~energycap.sdk.models.UserChild
    :param shared_list: Is this a list shared with anyone?
    :type shared_list: bool
    :param visible: Is this list visible to me?
    :type visible: bool
    """

    _attribute_map = {
        'list_id': {'key': 'listId', 'type': 'int'},
        'list_info': {'key': 'listInfo', 'type': 'str'},
        'list_description': {'key': 'listDescription', 'type': 'str'},
        'list_type': {'key': 'listType', 'type': 'ListTypeChild'},
        'user': {'key': 'user', 'type': 'UserChild'},
        'shared_list': {'key': 'sharedList', 'type': 'bool'},
        'visible': {'key': 'visible', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(ListCreateResponse, self).__init__(**kwargs)
        self.list_id = kwargs.get('list_id', None)
        self.list_info = kwargs.get('list_info', None)
        self.list_description = kwargs.get('list_description', None)
        self.list_type = kwargs.get('list_type', None)
        self.user = kwargs.get('user', None)
        self.shared_list = kwargs.get('shared_list', None)
        self.visible = kwargs.get('visible', None)
