# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGDefaultSettingRequest(Model):
    """GHGDefaultSettingRequest.

    :param commodity_id: The Commodity ID <span
     class='property-internal'>Required (defined)</span>
    :type commodity_id: int
    :param scope_category_id: The Greenhouse Gas Scope category identifier
     <span class='property-internal'>Required (defined)</span>
    :type scope_category_id: int
    :param default_factor:
    :type default_factor: ~energycap.sdk.models.GHGDefaultFactor
    """

    _attribute_map = {
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'scope_category_id': {'key': 'scopeCategoryId', 'type': 'int'},
        'default_factor': {'key': 'defaultFactor', 'type': 'GHGDefaultFactor'},
    }

    def __init__(self, *, commodity_id: int=None, scope_category_id: int=None, default_factor=None, **kwargs) -> None:
        super(GHGDefaultSettingRequest, self).__init__(**kwargs)
        self.commodity_id = commodity_id
        self.scope_category_id = scope_category_id
        self.default_factor = default_factor
