# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGFactor(Model):
    """GHGFactor.

    :param factor_type: The GHG Factor type.
     Values for this field can be "use meter address" or "specific factor"
    :type factor_type: str
    :param factor_category:
    :type factor_category: ~energycap.sdk.models.GHGFactorCategory
    :param factor_id: The Factor Identifier
    :type factor_id: int
    :param factor_info: The Factor Info
    :type factor_info: str
    :param factor_description: The Factor Description
    :type factor_description: str
    """

    _attribute_map = {
        'factor_type': {'key': 'factorType', 'type': 'str'},
        'factor_category': {'key': 'factorCategory', 'type': 'GHGFactorCategory'},
        'factor_id': {'key': 'factorId', 'type': 'int'},
        'factor_info': {'key': 'factorInfo', 'type': 'str'},
        'factor_description': {'key': 'factorDescription', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(GHGFactor, self).__init__(**kwargs)
        self.factor_type = kwargs.get('factor_type', None)
        self.factor_category = kwargs.get('factor_category', None)
        self.factor_id = kwargs.get('factor_id', None)
        self.factor_info = kwargs.get('factor_info', None)
        self.factor_description = kwargs.get('factor_description', None)
