# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RollingComparisonDetail(Model):
    """RollingComparisonDetail.

    :param year_range:
    :type year_range: ~energycap.sdk.models.YearRange
    :param values: The monthly values within the year range
    :type values: list[~energycap.sdk.models.PeriodValue]
    """

    _attribute_map = {
        'year_range': {'key': 'yearRange', 'type': 'YearRange'},
        'values': {'key': 'values', 'type': '[PeriodValue]'},
    }

    def __init__(self, **kwargs):
        super(RollingComparisonDetail, self).__init__(**kwargs)
        self.year_range = kwargs.get('year_range', None)
        self.values = kwargs.get('values', None)
